Quick start guide — Django FileBrowser 3.13.2 documentation

# Quick start guide

For using the FileBrowser, Django needs to be installed and an Admin Site has to be activated.

## Requirements

- Django 3.1, http://www.djangoproject.com

- Grappelli 2.14, https://github.com/sehmaschine/django-grappelli

- Pillow, https://github.com/python-imaging/Pillow

## Installation

Install the FileBrowser:

    pip install django-filebrowser

Add the filebrowser to your `INSTALLED_APPS` (before django.contrib.admin):

    INSTALLED_APPS = (
        'grappelli',
        'filebrowser',
        'django.contrib.admin',
    )

Add the FileBrowser site to your url-patterns (before any admin-urls):

    from filebrowser.sites import site

    urlpatterns = [
       path('admin/filebrowser/', site.urls),
       path('grappelli/', include('grappelli.urls')),
       path('admin/', admin.site.urls),
    ]

Collect the static files (please refer to the Staticfiles Documentation for more information):

    python manage.py collectstatic

## Settings

Check the Settings.

Note

You need to add a folder “uploads” within `site.storage.location` when using the default settings.

## Testing

Start the devserver and login to your admin site:

    python manage.py runserver <IP-address>:8000

Goto /admin/filebrowser/browse/ and check if everything looks/works as expected. If you’re having problems, see Troubleshooting.